###################################################
### chunk number 1: 
###################################################
options(SweaveHooks=list(fig=function() par(bg="white")))
options(width=70)


###################################################
### chunk number 2: prepareData
###################################################
prep <- file.path("Tangled", "prepareData.R")
Stangle(file.path("RNowebSource", "prepareData.Rnw"), output=prep)
source(prep)
rm(prep)


###################################################
### chunk number 3: predictors
###################################################
pred <- file.path("Tangled", "predCellLines.R")
chem <- file.path("RDataObjects", "chemoPredictors.Rda")
if(file.exists(chem)) {
  load(chem)
} else {
  Stangle(file.path("RNowebSource", "predCellLines.Rnw"), output=pred)
  source(pred)
}
rm(pred, chem)


###################################################
### chunk number 4: pottiResponse
###################################################
pi <- predictorsInfo
pds <- which(pi[, "drugName"] == "Doce" & pi[, "responseStatus"] == "Sensitive")
pdr <- which(pi[, "drugName"] == "Doce" & pi[, "responseStatus"] == "Resistant")
pottiCellnameDoceSens <- as.character(pi$Source)[pds]
pottiCellnameDoceResi <- as.character(pi$Source)[pdr]
rm(pi,pds, pdr)


###################################################
### chunk number 5: psens
###################################################
cat(paste(pottiCellnameDoceSens, collapse=", "))


###################################################
### chunk number 6: presi
###################################################
cat(paste(pottiCellnameDoceResi, collapse=", "))


###################################################
### chunk number 7: nscdoce
###################################################
doceNSC <- as.character(nsc["Doce"])
doceNSC


###################################################
### chunk number 8: paranoia
###################################################
sum(colnames(LC50)!=colnames(TGI))
sum(colnames(LC50)!=colnames(GI50))


###################################################
### chunk number 9: lc50
###################################################
getOption("SweaveHooks")[["fig"]]()
isDocetaxel <- which(regexpr(doceNSC, colnames(GI50))>0)
pairs(LC50[, isDocetaxel], main="LC50")


###################################################
### chunk number 10: tgi
###################################################
getOption("SweaveHooks")[["fig"]]()
pairs(TGI[, isDocetaxel], main="TGI")


###################################################
### chunk number 11: gi50
###################################################
getOption("SweaveHooks")[["fig"]]()
pairs(GI50[, isDocetaxel], main="GI50")


###################################################
### chunk number 12: extraction
###################################################
doceGI50 <- as.vector((apply(GI50[, isDocetaxel[2:3]], 1, mean, na.rm=TRUE)))
doceLC50 <- as.vector((LC50[, isDocetaxel[1]]))
doceTGI <- as.vector((TGI[, isDocetaxel[1]]))
names(doceGI50) <- rownames(GI50)
names(doceLC50) <- rownames(LC50)
names(doceTGI) <- rownames(TGI)
rm(isDocetaxel)


###################################################
### chunk number 13: missing
###################################################
missing <- names(doceGI50)[is.na(doceGI50) | is.na(doceTGI)]
missing


###################################################
### chunk number 14: ick
###################################################
quantCut <- 0.335
cellLineNames <- function(v) names(doceGI50[v])
temp <- doceGI50 > quantile(doceGI50, 1-quantCut, na.rm=TRUE) &
           doceTGI > quantile(doceTGI, 1-quantCut, na.rm=TRUE) &
           !is.na(doceGI50) & !is.na(doceTGI)
ourCellnameDoceSens <- cellLineNames(temp)
temp <- doceGI50 < quantile(doceGI50, quantCut, na.rm=TRUE) & 
           doceTGI < quantile(doceTGI, quantCut, na.rm=TRUE) & 
           !is.na(doceGI50) & !is.na(doceTGI)
ourCellnameDoceResi <- cellLineNames(temp)
rm(missing, temp)


###################################################
### chunk number 15: osens
###################################################
cat(paste(ourCellnameDoceSens, collapse=", "))


###################################################
### chunk number 16: oresi
###################################################
cat(paste(ourCellnameDoceResi, collapse=", "))


###################################################
### chunk number 17: doce
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(doceGI50, doceTGI, pch=16,xlab="NLOG GI50", ylab="NLOG TGI")
points(doceGI50[ourCellnameDoceSens], doceTGI[ourCellnameDoceSens], 
       pch=15, col="green")
points(doceGI50[ourCellnameDoceResi], doceTGI[ourCellnameDoceResi], 
       pch=15, col="red")
points(doceGI50[pottiCellnameDoceSens], doceTGI[pottiCellnameDoceSens],
       pch=1, cex=2, col="green")
points(doceGI50[pottiCellnameDoceResi], doceTGI[pottiCellnameDoceResi], 
       pch=1, cex=2, col="red")
legend(6,8, c("Sensitive", "Resistant", "Sensitive (Potti)", "Resistant (Potti)", 
              "Other Cell Lines"), 
       col=c("green", "red", "green", "red", "black"), pch=c(15, 15, 1, 1, 16))
abline(v=quantile(doceGI50, c(quantCut, 1-quantCut), na.rm=TRUE),
       h=quantile(doceTGI, c(quantCut, 1-quantCut), na.rm=TRUE))
title(paste("Removed Central ", 100*(1-2*quantCut), "%", sep=''))


###################################################
### chunk number 18: threeway
###################################################
getOption("SweaveHooks")[["fig"]]()
foo <- function(xn, yn) {
  x <- eval(as.name(paste("doce", xn, sep="")))
  y <- eval(as.name(paste("doce", yn, sep="")))
  plot(x, y, pch=16, xlab=paste("NLOG", xn), ylab=paste("NLOG", yn))
  points(x[ourCellnameDoceSens], y[ourCellnameDoceSens], pch=15, col="green")
  points(x[ourCellnameDoceResi], y[ourCellnameDoceResi], pch=15, col="red")
  points(x[pottiCellnameDoceSens], y[pottiCellnameDoceSens], pch=1, cex=2, col="green")
  points(x[pottiCellnameDoceResi], y[pottiCellnameDoceResi], pch=1, cex=2, col="red")
}
par(mfrow=c(2,2))
foo("GI50", "TGI")
foo("LC50", "TGI")
foo("GI50", "LC50")
par(mfrow=c(1,1))
rm(foo)


###################################################
### chunk number 19: ms
###################################################
m <- mean(doceGI50, na.rm=TRUE)
s <- sd(doceGI50, na.rm=TRUE)
gsen <- cellLineNames(!is.na(doceGI50) & doceGI50 > m+s)
gres <- cellLineNames(!is.na(doceGI50) & doceGI50 < m-s)
gres
gsen


###################################################
### chunk number 20: ms
###################################################
pottiCellnameDoceResi[which(pottiCellnameDoceResi %in% gres)]
pottiCellnameDoceSens[which(pottiCellnameDoceSens %in% gsen)]


###################################################
### chunk number 21: pr
###################################################
pottiRule <- function(i, strict=FALSE) {
  if(!i %in% c(4, 6, 7))
    stop("The only valid starting concentrations are 4, 6, and 7")
  expt <- paste(doceNSC, "L-", i, sep="")
  gi50 <- GI50[,expt]
  gm <- mean(gi50, na.rm=TRUE)
  gs <- sd(gi50, na.rm=TRUE)
  tgi <- TGI[,expt]
  tm <- median(tgi, na.rm=TRUE)
  lc50 <- LC50[,expt]
  lm <- median(lc50, na.rm=TRUE)
  valid <- !is.na(gi50) & !is.na(tgi) & !is.na(lc50)
  if (strict) {
    sens <- which(valid & (gi50 > gm + gs) & (tgi > tm) & (lc50 > lm))
    resi <- which(valid & (gi50 < gm - gs) & (tgi < tm) & (lc50 < lm))
  } else {
    sens <- which(valid & (gi50 > gm + gs) & (tgi >= tm) & (lc50 >= lm))
    resi <- which(valid & (gi50 < gm - gs) & (tgi <= tm) & (lc50 <= lm))
  }
  list(sens=sens, resi=resi)
}


###################################################
### chunk number 22: p4
###################################################
pottiRule(4)
pottiRule(4, strict=TRUE)


###################################################
### chunk number 23: p6
###################################################
pottiRule(6)
pottiRule(6, strict=TRUE)


###################################################
### chunk number 24: p7
###################################################
pottiRule(7)
pottiRule(7, strict=TRUE)


###################################################
### chunk number 25: cleanup
###################################################
rm(m, s, gsen, gres)


###################################################
### chunk number 26: saver
###################################################
save(cellLineNames, doceNSC, doceGI50, doceLC50, doceTGI,
     quantCut, ourCellnameDoceSens, ourCellnameDoceResi, 
     pottiCellnameDoceSens, pottiCellnameDoceResi, 
     file=file.path("RDataObjects", "doceGI50.Rda"))


