###################################################
### chunk number 1: 
###################################################
options(SweaveHooks=list(fig=function() par(bg="white")))
options(width=70)


###################################################
### chunk number 2: prepareData
###################################################
prep <- file.path("Tangled", "prepareData.R")
Stangle(file.path("RNowebSource", "prepareData.Rnw"), output=prep)
source(prep)
rm(prep)


###################################################
### chunk number 3: getCached
###################################################
getCached <- function(rda, r) {
  rfile <- file.path("Tangled", paste(r, "R", sep="."))
  rdafile <- file.path("RDataObjects", paste(rda, "Rda", sep="."))
  if(file.exists(rdafile)) {
    cat("loading from cache\n")
    load(rdafile, .GlobalEnv)
  } else {
    Stangle(file.path("RNowebSource", paste(r, "Rnw", sep=".")), output=rfile)
    source(rfile)
  }
}


###################################################
### chunk number 4: getItAll
###################################################
getCached("chemoPredictors", "predCellLines")
getCached("doceGI50", "gi50ValuesOverlap")
getCached("features", "wobblingFeatures")


###################################################
### chunk number 5: makePcaModel
###################################################
makePcaModel <- function(data, info, features) {
  require(ClassDiscovery)
  batchdata <- data[features,]
  spca <- SamplePCA(batchdata, info$Response)#$

  pcaScores <- data.frame(spca@scores)
  N <- ncol(pcaScores)
  dimnames(pcaScores) <- list(colnames(batchdata), 
                            paste("PC", 1:N, sep=""))
  pcaScores <- data.frame(Response=info$Response, pcaScores) #$

  temp <- pcaScores[, c(1, 3:21)]
  allButOne <- glm(Response ~ . , data=temp, family=binomial(link=probit))

  temp <- pcaScores[, 1:21]
  massive <- glm(Response ~ ., data=temp, family=binomial(link=probit))
  justOne <- glm(Response ~ PC1, data=temp, family=binomial(link=probit))
  better <- step(massive, trace=0)
  list(spca=spca, allButOne=allButOne, better=better, justOne=justOne, 
       info=info, features=features)
}


###################################################
### chunk number 6: model
###################################################
ourModelA <- makePcaModel(ourSubset$NL, ourSubset$Info, ourStuff$Features$A)
ourModelAvg <- makePcaModel(ourSubset$NL, ourSubset$Info, ourStuff$Features$Average)
pottiModelA <- makePcaModel(pottiSubset$NL, pottiSubset$Info, pottiStuff$Features$A)
pottiModelAvg <- makePcaModel(pottiSubset$NL, pottiSubset$Info, pottiStuff$Features$Average)
pottiModelRpt <- makePcaModel(pottiSubset$NL, pottiSubset$Info, pottiOBOE)


###################################################
### chunk number 7: attach1
###################################################
require(colorspace)
attach(ourModelA)


###################################################
### chunk number 8: spca1
###################################################
getOption("SweaveHooks")[["fig"]]()
# note that the levels of the response variable are "Resistant" and
# "Sensitive", so the first (Resistant) level gets colored "red".
plot(spca, col=c("red", "green"))
legend(-3,-4, c("Sensitive", "Resistant"), col=c("green", "red"), pch=16)


###################################################
### chunk number 9: extra1
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(spca, split=info$cellname) #$


###################################################
### chunk number 10: anova1
###################################################
anova(allButOne, test="Chi")


###################################################
### chunk number 11: againanova1
###################################################
anova(better, test="Chi")


###################################################
### chunk number 12: attach2
###################################################
detach("ourModelA")
attach(ourModelAvg)


###################################################
### chunk number 13: spca2
###################################################
getOption("SweaveHooks")[["fig"]]()
# note that the levels of the response variable are "Resistant" and
# "Sensitive", so the first (Resistant) level gets colored "red".
plot(spca, col=c("red", "green"))
legend(-10,-5, c("Sensitive", "Resistant"), col=c("green", "red"), pch=16)


###################################################
### chunk number 14: extra2
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(spca, split=info$cellname) #$


###################################################
### chunk number 15: anova2
###################################################
anova(allButOne, test="Chi")


###################################################
### chunk number 16: againanova2
###################################################
anova(better, test="Chi")


###################################################
### chunk number 17: attach3
###################################################
detach("ourModelAvg")
attach(pottiModelA)


###################################################
### chunk number 18: spca3
###################################################
getOption("SweaveHooks")[["fig"]]()
# note that the levels of the response variable are "Resistant" and
# "Sensitive", so the first (Resistant) level gets colored "red".
plot(spca, col=c("red", "green"))
legend(-10, 5, c("Sensitive", "Resistant"), col=c("green", "red"), pch=16)


###################################################
### chunk number 19: extra3
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(spca, split=info$cellname) #$


###################################################
### chunk number 20: anova3
###################################################
anova(allButOne, test="Chi")


###################################################
### chunk number 21: againanova3
###################################################
anova(better, test="Chi")


###################################################
### chunk number 22: attach4
###################################################
detach("pottiModelA")
attach(pottiModelAvg)


###################################################
### chunk number 23: spca4
###################################################
getOption("SweaveHooks")[["fig"]]()
# note that the levels of the response variable are "Resistant" and
# "Sensitive", so the first (Resistant) level gets colored "red".
plot(spca, col=c("red", "green"))
legend(-4,6, c("Sensitive", "Resistant"), col=c("green", "red"), pch=16)


###################################################
### chunk number 24: extra4
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(spca, split=info$cellname) #$


###################################################
### chunk number 25: anova4
###################################################
anova(allButOne, test="Chi")


###################################################
### chunk number 26: againanova4
###################################################
anova(better, test="Chi")


###################################################
### chunk number 27: attach4
###################################################
detach("pottiModelAvg")
attach(pottiModelRpt)


###################################################
### chunk number 28: spca5
###################################################
getOption("SweaveHooks")[["fig"]]()
# note that the levels of the response variable are "Resistant" and
# "Sensitive", so the first (Resistant) level gets colored "red".
plot(spca, col=c("red", "green"))
legend(-4,4, c("Sensitive", "Resistant"), col=c("green", "red"), pch=16)


###################################################
### chunk number 29: extra5
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(spca, split=info$cellname) #$


###################################################
### chunk number 30: anova5
###################################################
anova(allButOne, test="Chi")


###################################################
### chunk number 31: againanova5
###################################################
anova(better, test="Chi")


###################################################
### chunk number 32: detach
###################################################
detach("pottiModelRpt")


###################################################
### chunk number 33: clean
###################################################
rm(makePcaModel)


###################################################
### chunk number 34: save
###################################################
save(pottiModelA, pottiModelAvg, pottiModelRpt,
     ourModelA, ourModelAvg, file=file.path("RDataObjects", "pcaModels.Rda"))


