###################################################
### chunk number 1: 
###################################################
options(SweaveHooks=list(fig=function() par(bg="white")))
options(width=70)


###################################################
### chunk number 2: setup
###################################################
prep <- file.path("Tangled", "prepareData.R")
Stangle(file.path("RnowebSource", "prepareData.Rnw"), output=prep)
source(prep)


###################################################
### chunk number 3: loadPredictors
###################################################
dukeDir <- file.path("..", "PublicData", "DukeWebSite")
predictors <- read.table(file.path(dukeDir, "Chemo predictors (U-95).csv"),
                         sep=",",  header=TRUE);
rownames(predictors) <- as.character(predictors[,"probe_set"]);
predictors <- predictors[,2:ncol(predictors)];
dim(predictors)


###################################################
### chunk number 4: loadInfo
###################################################
drugList <- c("Adria", "Etopo", "X5.FU", "Cytox", "Topo", "Taxol", "Doce")
drugName <- rep("Unknown", ncol(predictors))
drugLevel <- drugName;
for(i1 in 1:length(drugList)){
  temp <- grep(paste("^", drugList[i1], sep=""), colnames(predictors));
  drugName[temp[1]:temp[2]] <- drugList[i1];
  if(any(grep(paste("^", drugList[i1], "0", sep=""),
              colnames(predictors)[temp[1]]))){
    drugLevel[temp[1]] <- "Resistant";
    drugLevel[temp[2]] <- "Sensitive";
  } else {
    drugLevel[temp[1]] <- "Sensitive";
    drugLevel[temp[2]] <- "Resistant";
  }
}
drugName[drugName == "X5.FU"] <- "5-FU";
drugLevel[grep("^X0", colnames(predictors))] <- "Resistant";
drugLevel[grep("^X1", colnames(predictors))] <- "Sensitive";
#drugLevel[(drugName == "Doce") & (drugLevel == "Resistant")] <- "temp";
#drugLevel[(drugName == "Doce") & (drugLevel == "Sensitive")] <- "Resistant";
#drugLevel[(drugName == "Doce") & (drugLevel == "temp")] <- "Sensitive";


###################################################
### chunk number 5: novu
###################################################
rownames(predictors)[1]
rownames(novartis)[1]
dim(novartis)
length(unique(novartis[1,]))


###################################################
### chunk number 6: getLine
###################################################
temp <- unique(t(predictors["36460_at",]));
nLinesUsed <- length(temp);
lineIndicator <- match(t(predictors["36460_at",]), temp);


###################################################
### chunk number 7: testLines
###################################################
passFail <- rep("Fail", nLinesUsed);
for(i1 in 1:nLinesUsed){
  temp <- which(lineIndicator == i1);
  if(all(rep(predictors[,temp[1]], length(temp)) ==
         predictors[,temp])){
    passFail[i1] <- "Pass";
  }
}
if(all(passFail == "Pass")){
  "all passed"
}else{
  "some failed"
}


###################################################
### chunk number 8: setInfo
###################################################
predictorsInfo <- 
  data.frame(index = c(1:(dim(predictors)[2])),
             drugName = as.factor(drugName),
             responseStatus = as.factor(drugLevel),
             lineIndicator = as.factor(lineIndicator));
rm(i1, temp, passFail, drugList, drugName, drugLevel)
rm(nLinesUsed, lineIndicator);


###################################################
### chunk number 9: nov
###################################################
nov <- data.frame(novartisInfo, Signal=as.vector(as.matrix(novartis["36460_at",])))
summary(nov)
length(levels(nov[, "cellname"]))


###################################################
### chunk number 10: src
###################################################
x <- nov[, "Signal"]
y <- as.vector(as.matrix(predictors["36460_at",]))
src <- rep(NA, length(y))
for(i in 1:length(src)) {
  temp <- which(x==y[i])
  if (length(temp) > 1) {
    stop("multiple hits")
  } else if (length(temp) == 1) {
    src[i] <- temp
  }
}
predictorsInfo[, "SourceIndex"] <- src
predictorsInfo[, "SourceID"] <- nov[src, "ID"]
predictorsInfo[, "Source"] <- nov[src, "cellname"]
rm(i, x, y, temp)
predictorsInfo[,c(2,3,5,6,7)];


###################################################
### chunk number 11: used
###################################################
used <- rep(FALSE, nrow(nov))
temp <- unique(src)
used[temp] <- TRUE
nov[,"Used"] <- used
sum(nov[, "Used"])


###################################################
### chunk number 12: aselect
###################################################
attach(nov)
table(ID, Used)
detach()


###################################################
### chunk number 13: ps
###################################################
predictorsSubset <- rownames(novartis) %in% rownames(predictors)
sum(predictorsSubset)


###################################################
### chunk number 14: notpot
###################################################
rownames(novartis)[!predictorsSubset]


###################################################
### chunk number 15: ordering
###################################################
sum(rownames(predictors) == rownames(novartis)[predictorsSubset])
sum(rownames(predictors) != rownames(novartis)[predictorsSubset])


###################################################
### chunk number 16: matchup
###################################################
i <- 5
identifier <- paste(predictorsInfo[i, "SourceID"],
                    predictorsInfo[i, "Source"], sep='.')
matching <- which(colnames(novartis) == identifier)
x <- predictors[,i]
y <- novartis[predictorsSubset, matching]
summary(x-y)


###################################################
### chunk number 17: lastClean
###################################################
rm(i, identifier, matching, src, temp, used, x, y, dukeDir);
predictorsInfo[, "NovartisName"] <- 
  colnames(novartis)[match(predictors["36460_at",],
                           novartis["36460_at",])];
predictorsInfo <- 
  predictorsInfo[,c("index", "drugName", "responseStatus",
                    "Source", "NovartisName")];
save(predictors, predictorsInfo, predictorsSubset, 
     file=file.path("RDataObjects", "chemoPredictors.Rda"))



