###################################################
### chunk number 1: 
###################################################
options(SweaveHooks=list(fig=function() par(bg="white")))
options(width=70)


###################################################
### chunk number 2: prepareData
###################################################
prep <- file.path("Tangled", "prepareData.R")
Stangle(file.path("RNowebSource", "prepareData.Rnw"), output=prep)
source(prep)
rm(prep)


###################################################
### chunk number 3: getCached
###################################################
getCached <- function(rda, r) {
  rfile <- file.path("Tangled", paste(r, "R", sep="."))
  rdafile <- file.path("RDataObjects", paste(rda, "Rda", sep="."))
  if(file.exists(rdafile)) {
    cat("loading from cache\n")
    load(rdafile, .GlobalEnv)
  } else {
    Stangle(file.path("RNowebSource", paste(r, "Rnw", sep=".")), output=rfile)
    source(rfile)
  }
}


###################################################
### chunk number 4: getItAll
###################################################
getCached("chemoPredictors", "predCellLines")
getCached("doceGI50", "gi50ValuesOverlap")
getCached("features", "wobblingFeatures")
getCached("pcaModels", "pca")
getCached("changData", "prepareChang")


###################################################
### chunk number 5: libs
###################################################
library(ClassComparison)
library(ClassDiscovery)


###################################################
### chunk number 6: changColors
###################################################
changColors <- c("orange", "blue")[as.numeric(changInfo[, "Response"])]
data.frame(changInfo, changColors)


###################################################
### chunk number 7: valPredictions
###################################################
valPredictions <- function(model, valdata, valinfo) {
  makePredictions <- function(data, model, info) {
    train <- predict(model, type="response") > 0.5
    tab <- table(train, info$Response) #$
    preds <- colnames(tab)[order(tab[2,])]
    preds[1 + as.numeric(predict(model, newdata=temp, type="response") > 0.5)]
  }
  valsubset <- valdata[model$features,]
  projection <- predict(model$spca, newdata=valsubset)  

  temp <- data.frame(projection)
  N <- ncol(temp)
  dimnames(temp) <- list(colnames(valdata), paste("PC", 1:N, sep=""))
  psens1 <- makePredictions(temp, model$justOne, model$info)
  psens <- makePredictions(temp, model$better, model$info)
  list(projection=projection, psens=psens, psens1=psens1, spca=model$spca) #$
}


###################################################
### chunk number 8: validate
###################################################
vOAS <- valPredictions(ourModelA,     changSoftNL, changInfo)
vOMS <- valPredictions(ourModelAvg,   changSoftNL, changInfo)
vPAS <- valPredictions(pottiModelA,   changSoftNL, changInfo)
vPMS <- valPredictions(pottiModelAvg, changSoftNL, changInfo)
vPRS <- valPredictions(pottiModelRpt, changSoftNL, changInfo)

vOAD <- valPredictions(ourModelA,     changDChipNL, changInfo)
vOMD <- valPredictions(ourModelAvg,   changDChipNL, changInfo)
vPAD <- valPredictions(pottiModelA,   changDChipNL, changInfo)
vPMD <- valPredictions(pottiModelAvg, changDChipNL, changInfo)
vPRD <- valPredictions(pottiModelRpt, changDChipNL, changInfo)


###################################################
### chunk number 9: plotval
###################################################
plotval <- function(val, ...) {
  xl <- ceiling(max(abs(c(val$spca@scores[,1], val$projection[,1])))/3)*3
  yl <- ceiling(max(abs(c(val$spca@scores[,2], val$projection[,2])))/3)*3
  plot(val$spca, #$
       col=c("red", "green"), xlim=c(-xl, xl), ylim=c(-yl, yl), ...)
  points(val$projection[,1], val$projection[,2], col=changColors, pch=16, cex=1.2)
  invisible(val)
}
legval <- function(x, y) {
  legend(x, y, c("NCI60 Sensitive", "NCI60 Resistant", 
                    "Chang Sensitive (Resp)", "Chang Resistant (NR)"), 
         col=c("green", "red", "blue", "orange"), 
         pch=c(15, 15, 16, 16))
}


###################################################
### chunk number 10: projpca1
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vOAS, main="Our Cells, Novartis A, Chang SOFT")
legval(-12, 12)


###################################################
### chunk number 11: justone
###################################################
table(vOAS$psens1, changInfo$Response)


###################################################
### chunk number 12: pcall
###################################################
table(vOAS$psens, changInfo$Response)


###################################################
### chunk number 13: projpca2
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vOMS, main="Our Cells, average, Chang SOFT")
legval(-12, 9)


###################################################
### chunk number 14: justone
###################################################
table(vOMS$psens1, changInfo$Response)


###################################################
### chunk number 15: pcall
###################################################
table(vOMS$psens, changInfo$Response)


###################################################
### chunk number 16: projpca3
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vPAS, main="Potti Cells, Novartis A, Chang SOFT")
legval(-12, -4)


###################################################
### chunk number 17: justone
###################################################
table(vPAS$psens1, changInfo$Response)


###################################################
### chunk number 18: pcall
###################################################
table(vPAS$psens, changInfo$Response)


###################################################
### chunk number 19: projpca4
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vPMS, main="Potti Cells, average, Chang SOFT")
legval(-9, -6)


###################################################
### chunk number 20: justone
###################################################
table(vPMS$psens1, changInfo$Response)


###################################################
### chunk number 21: pcall
###################################################
table(vPMS$psens, changInfo$Response)


###################################################
### chunk number 22: projpca5
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vPRS, main="Potti Cells, reported, Chang SOFT")
legval(-9, 6)


###################################################
### chunk number 23: justone
###################################################
table(vPRS$psens1, changInfo$Response)


###################################################
### chunk number 24: pcall
###################################################
table(vPRS$psens, changInfo$Response)


###################################################
### chunk number 25: projpca6
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vOAD, main="Our Cells, Novartis A, Chang dChip")
legval(-12,12)


###################################################
### chunk number 26: justone
###################################################
table(vOAD$psens1, changInfo$Response)


###################################################
### chunk number 27: pcall
###################################################
table(vOAD$psens, changInfo$Response)


###################################################
### chunk number 28: projpca7
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vOMD, main="Our Cells, average, Chang dChip")
legval(-12,9)


###################################################
### chunk number 29: justone
###################################################
table(vOMD$psens1, changInfo$Response)


###################################################
### chunk number 30: pcall
###################################################
table(vOMD$psens, changInfo$Response)


###################################################
### chunk number 31: projpca8
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vPAD, main="Potti Cells, Novartis A, Chang dChip")
legval(-12,-3)


###################################################
### chunk number 32: justone
###################################################
table(vPAD$psens1, changInfo$Response)


###################################################
### chunk number 33: pcall
###################################################
table(vPAD$psens, changInfo$Response)


###################################################
### chunk number 34: projpca9
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vPMD, main="Potti Cells, average, Chang dChip")
legval(-9, -4)


###################################################
### chunk number 35: justone
###################################################
table(vPMD$psens1, changInfo$Response)


###################################################
### chunk number 36: pcall
###################################################
table(vPMD$psens, changInfo$Response)


###################################################
### chunk number 37: projpca10
###################################################
getOption("SweaveHooks")[["fig"]]()
plotval(vPRD, main="Potti Cells, reported, Chang dChip")
legval(-9,6)


###################################################
### chunk number 38: justone
###################################################
table(vPRD$psens1, changInfo$Response)


###################################################
### chunk number 39: pcall
###################################################
table(vPRD$psens, changInfo$Response)


###################################################
### chunk number 40: save
###################################################
save(valPredictions, plotval, legval, changColors,
     vOAS, vOMS, vPAS, vPMS, vPRS,
     vOAD, vOMD, vPAD, vPMD, vPRD,
     file=file.path("RDataObjects", "predict.Rda"))


