###################################################
### chunk number 1: 
###################################################
options(SweaveHooks=list(fig=function() par(bg="white")))
options(width=70)


###################################################
### chunk number 2: prepareData
###################################################
prep <- file.path("Tangled", "prepareData.R")
Stangle(file.path("RNowebSource", "prepareData.Rnw"), output=prep)
source(prep)
rm(prep)


###################################################
### chunk number 3: getCached
###################################################
getCached <- function(rda, r) {
  rfile <- file.path("Tangled", paste(r, "R", sep="."))
  rdafile <- file.path("RDataObjects", paste(rda, "Rda", sep="."))
  if(file.exists(rdafile)) {
    cat("loading from cache\n")
    load(rdafile, .GlobalEnv)
  } else {
    Stangle(file.path("RNowebSource", paste(r, "Rnw", sep=".")), output=rfile)
    source(rfile)
  }
}


###################################################
### chunk number 4: getFeatures
###################################################
getCached("features", "wobblingFeatures")


###################################################
### chunk number 5: getResistant
###################################################
softDir <- file.path("..", "PublicData", "Chang", "Soft")
if (R.version$os == "mingw32") { #$
  temp <- system(paste("find /N \"Sample_geo_accession\" ",
                       file.path(softDir, "GSE349_family.soft")),
                 intern=TRUE)
  temp <- strsplit(temp, " = ")
  temp <- unlist(temp) 
  resistantNames <- temp[seq(from=3, to=length(temp), by=2)]
  temp <- system(paste("find /N \"sample_table_begin\" ",
                       file.path(softDir, "GSE349_family.soft")),
                 intern=TRUE)
  temp <- sub("\\\[", "", temp)
  temp <- strsplit(temp, "]")
  temp <- unlist(temp)
  startRows <- as.numeric(temp[seq(from=2, to=length(temp), by=2)])
  rm(temp)
} else {
  temp <- system(paste("grep -n Sample_geo_accession ",
                       file.path(softDir, "GSE349_family.soft")),
                 intern=TRUE)
  temp <- strsplit(temp, " = ")
  temp <- unlist(temp) 
  resistantNames <- temp[seq(from=2, to=length(temp), by=2)]
  temp <- system(paste("grep -n sample_table_begin ",
                       file.path(softDir, "GSE349_family.soft")),
                 intern=TRUE)
  temp <- strsplit(temp, ":")
  temp <- unlist(temp)
  startRows <- as.numeric(temp[seq(from=1, to=length(temp), by=2)])
  rm(temp)
}


###################################################
### chunk number 6: changRes
###################################################
nProbesets <- 12625
resistantData <- 
  data.frame(matrix(0, nProbesets, length(resistantNames)))
colnames(resistantData) <- resistantNames
temp <- read.table(file.path(softDir, "GSE349_family.soft"),
                   nrows=nProbesets, skip=startRows[1],
                   header=TRUE, row.names="ID_REF")
rownames(resistantData) <- rownames(temp)
resistantData[,1] <- temp$VALUE
for(i1 in 2:length(startRows)){
  temp <- read.table(file.path(softDir, "GSE349_family.soft"),
                     nrows=nProbesets, skip=startRows[i1],
                     header=TRUE, row.names="ID_REF")
  resistantData[,i1] <- temp$VALUE[match(rownames(resistantData),
                                         rownames(temp))]
}


###################################################
### chunk number 7: getSensitive
###################################################
if (R.version$os == "mingw32") { #$
  temp <- system(paste("find /N \"Sample_geo_accession\" ",
                       file.path(softDir, "GSE350_family.soft")),
                 intern=TRUE)
  temp <- strsplit(temp, " = ")
  temp <- unlist(temp) 
  sensitiveNames <- temp[seq(from=3, to=length(temp), by=2)]
  temp <- system(paste("find /N \"sample_table_begin\" ",
                       file.path(softDir, "GSE350_family.soft")),
                 intern=TRUE)
  temp <- sub("\\\[", "", temp)
  temp <- strsplit(temp, "]")
  temp <- unlist(temp)
  startRows <- as.numeric(temp[seq(from=2, to=length(temp), by=2)])
  rm(temp)
} else {
  temp <- system(paste("grep -n Sample_geo_accession ",
                       file.path(softDir, "GSE350_family.soft")),
                 intern=TRUE)
  temp <- strsplit(temp, " = ")
  temp <- unlist(temp) 
  sensitiveNames <- temp[seq(from=2, to=length(temp), by=2)]
  temp <- system(paste("grep -n sample_table_begin ",
                       file.path(softDir, "GSE350_family.soft")),
                 intern=TRUE)
  temp <- strsplit(temp, ":")
  temp <- unlist(temp)
  startRows <- as.numeric(temp[seq(from=1, to=length(temp), by=2)])
  rm(temp)
}


###################################################
### chunk number 8: changSen
###################################################
sensitiveData <- 
  data.frame(matrix(0, nProbesets, length(sensitiveNames)))
colnames(sensitiveData) <- sensitiveNames
temp <- read.table(file.path(softDir, "GSE350_family.soft"),
                   nrows=nProbesets, skip=startRows[1],
                   header=TRUE, row.names="ID_REF")
rownames(sensitiveData) <- rownames(temp)
sensitiveData[,1] <- temp$VALUE
for(i1 in 2:length(startRows)){
  temp <- read.table(file.path(softDir, "GSE350_family.soft"),
                     nrows=nProbesets, skip=startRows[i1],
                     header=TRUE, row.names="ID_REF")
  sensitiveData[,i1] <- temp$VALUE[match(rownames(sensitiveData),
                                         rownames(temp))]
}
rm(softDir)


###################################################
### chunk number 9: changSoft
###################################################
badCol <- which(names(resistantData)=="GSM4913")
changSoft <- cbind(sensitiveData, 
                   resistantData[,badCol],
                   resistantData[,-badCol])
names(changSoft)[11] <- "GSM4913"


###################################################
### chunk number 10: changSoft
###################################################
changSoft <- changSoft[rownames(novartis),]


###################################################
### chunk number 11: changSoft
###################################################
changSoftStatus <- factor(rep(c("Resp", "NR"), times=c(11, 13)))
changInfo <- data.frame(GEO.ID=colnames(changSoft), Response=changSoftStatus)


###################################################
### chunk number 12: changDchip
###################################################
changDChip <- read.table(file.path("..", "PublicData", "Chang", "Chang expression.txt"),
                         sep="\t", header=TRUE, row.names=1)


###################################################
### chunk number 13: changDchip
###################################################
changDChip <- changDChip[rownames(novartis), colnames(changSoft)]


###################################################
### chunk number 14: getquant
###################################################
temp <- novartisNL
for(i in 1:ncol(temp)) temp[,i] <- sort(temp[,i])
nov.q <- sort(apply(temp, 1, median))


###################################################
### chunk number 15: changSoftNL
###################################################
changSoftNL <- changSoft
for(i in 1:ncol(changSoftNL))
  changSoftNL[,i] <- nov.q[rank(changSoft[,i])]


###################################################
### chunk number 16: changDchipNL
###################################################
changDChipNL <- changDChip
for(i in 1:ncol(changDChipNL))
  changDChipNL[,i] <- nov.q[rank(changDChip[,i])]


###################################################
### chunk number 17: nl
###################################################
getOption("SweaveHooks")[["fig"]]()
i <- 7
require(geneplotter)
smoothScatter(changSoftNL[,i], changDChipNL[,i], xlab="SOFT values", ylab="dChip PM-only values")
abline(0,1)


###################################################
### chunk number 18: nl2
###################################################
getOption("SweaveHooks")[["fig"]]()
i <- 7
smoothScatter(log(changSoft)[,i], log(changDChip)[,i], xlab="SOFT values", ylab="dChip PM-only values")
abline(0,1)


###################################################
### chunk number 19: clean
###################################################
rm(temp, badCol, i, i1, startRows, changSoftStatus, nov.q, nProbesets,
   resistantNames, resistantData, sensitiveNames, sensitiveData)


###################################################
### chunk number 20: save
###################################################
save(changInfo, changSoft, changSoftNL,
     changDChip, changDChipNL,
     file=file.path("RDataObjects", "changData.Rda"))


