###################################################
### chunk number 1: 
###################################################
options(SweaveHooks=list(fig=function() par(bg="white")))
options(width=70)


###################################################
### chunk number 2: prepareData
###################################################
prep <- file.path("Tangled", "prepareData.R")
Stangle(file.path("RNowebSource", "prepareData.Rnw"), output=prep)
source(prep)
rm(prep)


###################################################
### chunk number 3: getCached
###################################################
getCached <- function(rda, r) {
  rfile <- file.path("Tangled", paste(r, "R", sep="."))
  rdafile <- file.path("RDataObjects", paste(rda, "Rda", sep="."))
  if(file.exists(rdafile)) {
    cat("loading from cache\n")
    load(rdafile, .GlobalEnv)
  } else {
    Stangle(file.path("RNowebSource", paste(r, "Rnw", sep=".")), output=rfile)
    source(rfile)
  }
}


###################################################
### chunk number 4: getItAll
###################################################
getCached("chemoPredictors", "predCellLines")
getCached("doceGI50", "gi50ValuesOverlap")
getCached("features", "wobblingFeatures")
getCached("pcaModels", "pca")
getCached("changData", "prepareChang")
getCached("predict", "predict")


###################################################
### chunk number 5: libs
###################################################
library(ClassComparison)
library(ClassDiscovery)


###################################################
### chunk number 6: parameters
###################################################
trainStatus <- pottiCells
# later do this with ourCells
trainColors <- rep("red", length(trainStatus))
trainColors[trainStatus=="Sensitive"] <- "green"
nGenes <- 50
nPC <- 5
validationSet <- changSoftNL
validStatus <- changInfo[,"Response"]
validColors <- changColors


###################################################
### chunk number 7: chooseRandomTrainingSet
###################################################
novA <- novartisNL[, novartisInfo[,"ID"]=="A"]
N <- length(trainStatus)
randLn <- novA[,sample(ncol(novA), N)]


###################################################
### chunk number 8: selectFeaturesUsingTtest
###################################################
t.test.results <- MultiTtest(randLn, trainStatus)
topNRand <- order(t.test.results@p.values)[1:nGenes]
topTrainRand <- randLn[topNRand,]
topValidRand <- validationSet[topNRand,]


###################################################
### chunk number 9: getPrincipalComponents
###################################################
pcaTrainRand <- SamplePCA(topTrainRand, splitter=trainStatus)
projValidRand <- predict(pcaTrainRand, newdata=topValidRand)

trainPCRand <- pcaTrainRand@scores[, 1:nPC]
colnames(trainPCRand) <- paste("PC", 1:nPC, sep="")
trainPCRand <- data.frame(status=trainStatus, trainPCRand)

validPCRand <- as.data.frame(projValidRand[,1:nPC])
colnames(validPCRand) <- paste("PC", 1:nPC, sep="")


###################################################
### chunk number 10: spca
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(pcaTrainRand, col=levels(trainColors), main="Docetaxel Random Case")
points(projValidRand, col=validColors, pch=16)
legend(-9,-3, c("Sensitive", "Resistant", "NR", "Resp"), 
	col=c("green", "red", "orange", "blue"), pch=c(15, 15, 16, 16))


###################################################
### chunk number 11: buildProbitModel
###################################################
randModel <- glm(status ~ ., family=binomial(link=probit), data=trainPCRand)
randModelStep <- step(randModel, trace=0)


###################################################
### chunk number 12: modelSummaries
###################################################
summary(randModelStep)


###################################################
### chunk number 13: makePredictions
###################################################
trainRandPredictions <- predict(randModelStep, type="response")
validRandPredictions <- 
  predict(randModelStep, newdata=validPCRand, type="response")
temp1 <- table(trainStatus, trainRandPredictions > 0.5)
assignedLevels <- factor(validRandPredictions > 0.5, levels=c(FALSE, TRUE))
temp2 <- table(validStatus, assignedLevels)
if(temp1["Resistant", "FALSE"] > 5){
  dimnames(temp2)[[2]] <- c("Resistant", "Sensitive")
} else {
  dimnames(temp2)[[2]] <- c("Sensitive", "Resistant")
}
propnNRResistant <- temp2["NR","Resistant"]/sum(temp2["NR",])
propnRespSensitive <- temp2["Resp","Sensitive"]/sum(temp2["Resp",])
propnsRand <- c(propnNRResistant, propnRespSensitive)


###################################################
### chunk number 14: loopy
###################################################
loopy <- function(trainStatus, nGenes, nPC, validationSet) {
novA <- novartisNL[, novartisInfo[,"ID"]=="A"]
N <- length(trainStatus)
randLn <- novA[,sample(ncol(novA), N)]
t.test.results <- MultiTtest(randLn, trainStatus)
topNRand <- order(t.test.results@p.values)[1:nGenes]
topTrainRand <- randLn[topNRand,]
topValidRand <- validationSet[topNRand,]
pcaTrainRand <- SamplePCA(topTrainRand, splitter=trainStatus)
projValidRand <- predict(pcaTrainRand, newdata=topValidRand)

trainPCRand <- pcaTrainRand@scores[, 1:nPC]
colnames(trainPCRand) <- paste("PC", 1:nPC, sep="")
trainPCRand <- data.frame(status=trainStatus, trainPCRand)

validPCRand <- as.data.frame(projValidRand[,1:nPC])
colnames(validPCRand) <- paste("PC", 1:nPC, sep="")
randModel <- glm(status ~ ., family=binomial(link=probit), data=trainPCRand)
randModelStep <- step(randModel, trace=0)
trainRandPredictions <- predict(randModelStep, type="response")
validRandPredictions <- 
  predict(randModelStep, newdata=validPCRand, type="response")
temp1 <- table(trainStatus, trainRandPredictions > 0.5)
assignedLevels <- factor(validRandPredictions > 0.5, levels=c(FALSE, TRUE))
temp2 <- table(validStatus, assignedLevels)
if(temp1["Resistant", "FALSE"] > 5){
  dimnames(temp2)[[2]] <- c("Resistant", "Sensitive")
} else {
  dimnames(temp2)[[2]] <- c("Sensitive", "Resistant")
}
propnNRResistant <- temp2["NR","Resistant"]/sum(temp2["NR",])
propnRespSensitive <- temp2["Resp","Sensitive"]/sum(temp2["Resp",])
propnsRand <- c(propnNRResistant, propnRespSensitive)
return(propnsRand)
}


###################################################
### chunk number 15: simData
###################################################
nSims <- 200
propnMat <- matrix(NA, nSims, 2)
for (i in 1:nSims) {
  propnMat[i,] <- loopy(trainStatus, nGenes=50, nPC=5, validationSet=validationSet)
}


###################################################
### chunk number 16: mp
###################################################
vPerf <- function(vOAS, vStat) {
  ps <- factor(vOAS$psens, levels=c("Resistant", "Sensitive")) #$
  tab <- table(ps, vStat)
  spec <- tab[1,1]/sum(tab[,1]) 
  sens <- tab[2,2]/sum(tab[,2]) 
  list(sens=sens, spec=spec)
}


###################################################
### chunk number 17: plotRandom
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(c(0,1), c(0,1), type="n", 
     xlab="1 - Proportion of NR Cases called Resistant",
     ylab="Proportion of Resp Cases called Sensitive",
     main="Proportions Using Random Cell Lines")
points(1 - jitter(propnMat[,1]), jitter(propnMat[,2]))
abline(0, 1)
nullPAS <- vPerf(vPAS, validStatus)
points(1 - nullPAS$spec, nullPAS$sens, col="red", pch=15)
nullPMS <- vPerf(vPMS, validStatus)
points(1 - nullPMS$spec, nullPMS$sens, col="green", pch=15)
nullPRS <- vPerf(vPRS, validStatus)
points(1 - nullPRS$spec, nullPRS$sens, col="blue", pch=15)


###################################################
### chunk number 18: adder
###################################################
x <- apply(propnMat, 1, sum)/2
aucPAS <- sum(unlist(nullPAS))/2
aucPMS <- sum(unlist(nullPMS))/2
aucPRS <- sum(unlist(nullPRS))/2
mean(x > aucPAS)
mean(x > aucPMS)
mean(x > aucPRS)


###################################################
### chunk number 19: simData
###################################################
trainStatus <- ourCells
trainColors <- rep("red", length(trainStatus))
trainColors[trainStatus=="Sensitive"] <- "green"

nSims <- 200
ourMat <- matrix(NA, nSims, 2)
for (i in 1:nSims) {
  ourMat[i,] <- loopy(trainStatus, nGenes=50, nPC=5, validationSet=validationSet)
}


###################################################
### chunk number 20: plotRandom2
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(c(0,1), c(0,1), type="n", 
     xlab="1 - Proportion of NR Cases called Resistant",
     ylab="Proportion of Resp Cases called Sensitive",
     main="Proportions Using Random Cell Lines")
points(1 - jitter(ourMat[,1]), jitter(ourMat[,2]))
abline(0, 1)
nullOAS <- vPerf(vOAS, validStatus)
points(1 - nullOAS$spec, nullOAS$sens, col="red", pch=15)
nullOMS <- vPerf(vOMS, validStatus)
points(1 - nullOMS$spec, nullOMS$sens, col="green", pch=15)


###################################################
### chunk number 21: adder
###################################################
x <- apply(ourMat, 1, sum)/2
aucOAS <- sum(unlist(nullOAS))/2
aucOMS <- sum(unlist(nullOMS))/2
mean(x > aucOAS)
mean(x > aucOMS)


###################################################
### chunk number 22: save
###################################################
save(propnMat, ourMat, vPerf,
     file=file.path("RDataObjects", "randomCL.Rda"))


