###################################################
### chunk number 1: 
###################################################
options(SweaveHooks=list(fig=function() par(bg="white")))
options(width=70)


###################################################
### chunk number 2: prepareData
###################################################
prep <- file.path("Tangled", "prepareData.R")
Stangle(file.path("RNowebSource", "prepareData.Rnw"), output=prep)
source(prep)
rm(prep)


###################################################
### chunk number 3: predictors
###################################################
pred <- file.path("Tangled", "predCellLines.R")
chem <- file.path("RDataObjects", "chemoPredictors.Rda")
if(file.exists(chem)) {
  load(chem)
} else {
  Stangle(file.path("RNowebSource", "predCellLines.Rnw"), output=pred)
  source(pred)
}
rm(pred, chem)


###################################################
### chunk number 4: loadDoceGI50
###################################################
previous <- file.path("Tangled", "gi50ValuesOverlap.R")
docegi50 <- file.path("RDataObjects", "doceGI50.Rda")
if(file.exists(docegi50)) {
  load(docegi50)
} else {
  Stangle(file.path("RNowebSource", "gi50ValuesOverlap.Rnw"), output=previous)
  source(previous)
}
rm(previous, docegi50)


###################################################
### chunk number 5: affy
###################################################
library(affy)
library(ClassComparison)
library(ClassDiscovery)


###################################################
### chunk number 6: affy
###################################################
normed <- normalize.quantiles(as.matrix(novartis))
dimnames(normed) <- dimnames(novartis)
novartisNL <- log(normed, 2)
rm(normed)


###################################################
### chunk number 7: averaging
###################################################
L <- levels(novartisInfo$cellname)
temp <- sapply(L, function(x) {
  v <- novartisInfo$cellname==x
  1/sum(v)*v
})
novartisNLAvg <- novartisNL %*% temp
rm(L, temp)


###################################################
### chunk number 8: makeRSFactor
###################################################
makeRSFactor <- function(rn, sn) {
  temp <- c(rn, sn)
  resp <- rep(c("Resistant", "Sensitive"), times=c(length(rn), length(sn)))
  names(resp) <- c(rn, sn)
  factor(resp)
}
ourCells <- makeRSFactor(ourCellnameDoceResi, ourCellnameDoceSens)
pottiCells <- makeRSFactor(pottiCellnameDoceResi, pottiCellnameDoceSens)


###################################################
### chunk number 9: subsets
###################################################
makeSubset <- function(cellresp) {
  anc <- as.character(novartisInfo[, "cellname"])
  useful <- anc %in% names(cellresp)
  subnova <- novartisNL[, useful]
  subinfo <- novartisInfo[useful,]
  subinfo[,"Response"] <- cellresp[as.character(subinfo$cellname)]
  dangd <- which(subinfo$ID == "D")
  subinfo <- subinfo[-dangd,]
  subnova <- subnova[,-dangd]
  subinfo$ID <- factor(subinfo$ID)
  subinfo$cellname <- factor(subinfo$cellname)
  list(NL=subnova, Info=subinfo)
}
ourSubset <- makeSubset(ourCells)
pottiSubset <- makeSubset(pottiCells)


###################################################
### chunk number 10: topN
###################################################
top <- function(x, n, data) {
  target <- sort(x)[n]
  sort(rownames(data)[x <= target])
}


###################################################
### chunk number 11: parameters
###################################################
subinfo <- ourSubset$Info
subnova <- ourSubset$NL
theCells <- ourCells


###################################################
### chunk number 12: mtt.single
###################################################
mtt.a <- MultiTtest(subnova[,subinfo$ID=="A"],
                    subinfo[subinfo$ID=="A", "Response"])
bum.a <- Bum(mtt.a@p.values)
mtt.b <- MultiTtest(subnova[,subinfo$ID=="B"],
                    subinfo[subinfo$ID=="B", "Response"])
bum.b <- Bum(mtt.b@p.values)
mtt.c <- MultiTtest(subnova[,subinfo$ID=="C"],
                    subinfo[subinfo$ID=="C", "Response"])
bum.c <- Bum(mtt.c@p.values)


###################################################
### chunk number 13: mtt.joint
###################################################
mtt.joint <- MultiTtest(subnova, subinfo[, "Response"])
bum.joint <- Bum(mtt.joint@p.values)


###################################################
### chunk number 14: average
###################################################
mtt.average <- MultiTtest(novartisNLAvg[, names(theCells)], theCells)
bum.average <- Bum(mtt.average@p.values)


###################################################
### chunk number 15: topN
###################################################
N <- 50
average50 <- top(mtt.average@p.values, N, subnova)
joint50 <- top(mtt.joint@p.values, N, subnova)
a50 <- top(mtt.a@p.values, N, subnova)
b50 <- top(mtt.b@p.values, N, subnova)
c50 <- top(mtt.c@p.values, N, subnova)
alltogether <- sort(unique(c(average50,joint50, a50, b50, c50)))
getall <- which(rownames(subnova) %in% alltogether)
fiveP <- data.frame(Average=mtt.average@p.values,
                    Joint=mtt.joint@p.values,
                    A=mtt.a@p.values,
                    B=mtt.b@p.values,
                    C=mtt.c@p.values)[getall,]
library(hgu95av2)
sym <- unlist(mget(alltogether, envir=hgu95av2SYMBOL))
fiveP <- data.frame(GeneSymbol=sym, fiveP)


###################################################
### chunk number 16: getOverlap
###################################################
sew <- function(thread) {
  a <- rep(FALSE, length(alltogether))
  names(a) <- alltogether
  a[thread] <- TRUE
  a
}
temp <- 1*data.frame(Average=sew(average50), Joint=sew(joint50), 
                   A=sew(a50), B=sew(b50), C=sew(c50))
temp <- as.matrix(temp)
overlap <- t(temp) %*% temp
rm(temp)


###################################################
### chunk number 17: overlap
###################################################
library(xtable)
xtable(overlap, label="tab:overlap",
       caption="Overlap in the top 50 genes using different sets of replicate arrays.",
       digits=rep(0,6))


###################################################
### chunk number 18: computeFdr
###################################################
baz <- function(x, b) abs(50 - countSignificant(b, x))
fdr.a <- optimize(baz, c(0,1), b=bum.a)$minimum #$
fdr.b <- optimize(baz, c(0,1), b=bum.b)$minimum #$
fdr.c <- optimize(baz, c(0,1), b=bum.c)$minimum #$
fdr.joint <- optimize(baz, c(0,1), b=bum.joint)$minimum #$
fdr.average <- optimize(baz, c(0,1), b=bum.average)$minimum #$
rm(baz)


###################################################
### chunk number 19: fdr
###################################################
fdr.a
fdr.b
fdr.c
fdr.joint
fdr.average


###################################################
### chunk number 20: ourStuff
###################################################
write.table(fiveP, file=file.path("Results", "ourCells-pValues.tsv"),
            sep="\t", quote=FALSE, col.names=NA, na="")
ourStuff <- list(Features=list(Average=average50, Joint=joint50, A=a50, B=b50, C=c50),
                 FDR=list(Average=fdr.average, Joint=fdr.joint, A=fdr.a, B=fdr.b, C=fdr.c),
                 FiveP=fiveP,
                 Overlap=overlap)


###################################################
### chunk number 21: parameters
###################################################
subinfo <- pottiSubset$Info
subnova <- pottiSubset$NL
theCells <- pottiCells


###################################################
### chunk number 22: ReDoIt
###################################################
mtt.a <- MultiTtest(subnova[,subinfo$ID=="A"],
                    subinfo[subinfo$ID=="A", "Response"])
bum.a <- Bum(mtt.a@p.values)
mtt.b <- MultiTtest(subnova[,subinfo$ID=="B"],
                    subinfo[subinfo$ID=="B", "Response"])
bum.b <- Bum(mtt.b@p.values)
mtt.c <- MultiTtest(subnova[,subinfo$ID=="C"],
                    subinfo[subinfo$ID=="C", "Response"])
bum.c <- Bum(mtt.c@p.values)
mtt.joint <- MultiTtest(subnova, subinfo[, "Response"])
bum.joint <- Bum(mtt.joint@p.values)
mtt.average <- MultiTtest(novartisNLAvg[, names(theCells)], theCells)
bum.average <- Bum(mtt.average@p.values)
N <- 50
average50 <- top(mtt.average@p.values, N, subnova)
joint50 <- top(mtt.joint@p.values, N, subnova)
a50 <- top(mtt.a@p.values, N, subnova)
b50 <- top(mtt.b@p.values, N, subnova)
c50 <- top(mtt.c@p.values, N, subnova)
alltogether <- sort(unique(c(average50,joint50, a50, b50, c50)))
getall <- which(rownames(subnova) %in% alltogether)
fiveP <- data.frame(Average=mtt.average@p.values,
                    Joint=mtt.joint@p.values,
                    A=mtt.a@p.values,
                    B=mtt.b@p.values,
                    C=mtt.c@p.values)[getall,]
library(hgu95av2)
sym <- unlist(mget(alltogether, envir=hgu95av2SYMBOL))
fiveP <- data.frame(GeneSymbol=sym, fiveP)
sew <- function(thread) {
  a <- rep(FALSE, length(alltogether))
  names(a) <- alltogether
  a[thread] <- TRUE
  a
}
temp <- 1*data.frame(Average=sew(average50), Joint=sew(joint50), 
                   A=sew(a50), B=sew(b50), C=sew(c50))
temp <- as.matrix(temp)
overlap <- t(temp) %*% temp
rm(temp)


###################################################
### chunk number 23: overlap2
###################################################
library(xtable)
xtable(overlap, label="tab:overlap2",
       caption="Overlap in the top 50 genes using different sets of replicate arrays.",
       digits=rep(0,6))


###################################################
### chunk number 24: pottifdr
###################################################
baz <- function(x, b) abs(50 - countSignificant(b, x))
fdr.a <- optimize(baz, c(0,1), b=bum.a)$minimum #$
fdr.b <- optimize(baz, c(0,1), b=bum.b)$minimum #$
fdr.c <- optimize(baz, c(0,1), b=bum.c)$minimum #$
fdr.joint <- optimize(baz, c(0,1), b=bum.joint)$minimum #$
fdr.average <- optimize(baz, c(0,1), b=bum.average)$minimum #$
rm(baz)
fdr.a
fdr.b
fdr.c
fdr.joint
fdr.average


###################################################
### chunk number 25: pottiStuff
###################################################
write.table(fiveP, file=file.path("Results", "pottiCells-pValues.tsv"),
            sep="\t", quote=FALSE, col.names=NA, na="")
pottiStuff <- list(Features=list(Average=average50, Joint=joint50, A=a50, B=b50, C=c50),
                   FDR=list(Average=fdr.average, Joint=fdr.joint, A=fdr.a, B=fdr.b, C=fdr.c),
                   FiveP=fiveP,
                   Overlap=overlap)


###################################################
### chunk number 26: geneproc
###################################################
geneProc <- function(filename="../Original-info/Extracts/Table1.txt") {
  featureTables <- read.table(file=filename, sep="\n", quote="");

## At present, we have a factor with a huge number of levels.
## We want to make this into a list, with the drug names as
## the list element names, and vectors of probeset ids inside. 
  predictorEntries <- as.character(featureTables[,1]);

## find the group boundaries, and the associated probeset ids
  predictorBoundaries <- grep(pattern="PREDICTOR", predictorEntries, ignore.case=TRUE);
## drop the first line (overall header). This leaves
## 8 predictors, but the last is for PI3K and uses probeset
## ids from the U133 platform, so we won't use it here. 
  predictorBoundaries <- predictorBoundaries[2:9];
  probesetRows <- grep(pattern="_at$", predictorEntries); #$

  drugSignatures <- list();
  for(i1 in 1:7){
    drugSignatures[[i1]] <- predictorEntries[probesetRows[(probesetRows > predictorBoundaries[i1]) & (probesetRows < predictorBoundaries[i1+1])]];
  }
  names(drugSignatures) <- predictorEntries[predictorBoundaries[1:7]];

  return(drugSignatures)
}


###################################################
### chunk number 27: reported
###################################################
reportedFeatures <- geneProc(file.path("..", "PublicData", "NatureMedicine", "Table1.txt"))
pottiReportedDoce <- reportedFeatures$"DOCE" #$


###################################################
### chunk number 28: potti
###################################################
sum(pottiReportedDoce %in% rownames(ourStuff$FiveP))
sum(pottiReportedDoce %in% rownames(pottiStuff$FiveP))


###################################################
### chunk number 29: oboe
###################################################
pottiOBOE <- rownames(novartis)[1 + which(rownames(novartis) %in% pottiReportedDoce)]
sum(pottiOBOE %in% rownames(ourStuff$FiveP))
sum(pottiOBOE %in% rownames(pottiStuff$FiveP))
# now we get 29. from where?
sum(pottiOBOE %in% pottiStuff$Features$A)
sum(pottiOBOE %in% pottiStuff$Features$B)
sum(pottiOBOE %in% pottiStuff$Features$C)
sum(pottiOBOE %in% pottiStuff$Features$Joint)
sum(pottiOBOE %in% pottiStuff$Features$Batch)
# clearly, just from A



###################################################
### chunk number 30: clean
###################################################
rm(fiveP, getall, alltogether, sym, N)
rm(mtt.a, mtt.b, mtt.c, mtt.joint, mtt.average)
rm(makeSubset, makeRSFactor, top, sew) #??
rm(subinfo, subnova, overlap)
rm(bum.a, bum.b, bum.c, bum.average, bum.joint)
rm(fdr.a, fdr.b, fdr.c, fdr.average, fdr.joint)
rm(a50, b50, c50, average50, joint50)


###################################################
### chunk number 31: save
###################################################
save(ourStuff, ourCells, ourSubset,
     pottiStuff, pottiCells, pottiSubset, 
     novartisNL, novartisNLAvg, 
     reportedFeatures, pottiReportedDoce, pottiOBOE,
     file=file.path("RDataObjects", "features.Rda"))


###################################################
### chunk number 32: jets eval=FALSE
###################################################
## # do we ever use this now?
## source(file.path("..", "..", "OurAnalysis", "jet.colors.R"))
## jet <- jet.colors(64);


